/*
 * This file is part of essential.
 *
 *     essential is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     essential is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with essential.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.craftforge.essential.client;

/**
 * A client performs client requests.
 *
 * @author Christian Bick
 * @since 06.07.11
 */
public interface Client {

    /**
     * Performs a client request.
     *
     * @see ClientRequest
     *
     * @param request The client request
     * @return The client response
     */
    public ClientResponse performRequest(ClientRequest request);

    /**
     * Performs a client request and expects the specified HTTP status code
     * in the client response.
     *
     * @see ClientRequest
     * @see ClientResponse
     *
     * @param request The client request
     * @param expectedStatus The expected HTTP status code
     * @return The client response
     * @throws ClientException if the actual status does not match the expected status code
     */
    public ClientResponse performRequest(ClientRequest request, int expectedStatus) throws ClientException;

}
